@@ -130,7 +130,7 @@ TODO: Prevent crash if expr_src is unavailable when tracing...
 
 # TODO: Cache compiled ASTs!
 
-__version__ = "2.0"
+__version__ = "2.1"
 
 import sys
 import traceback
@@ -149,9 +149,19 @@ import textwrap
 # Globals #
 #---------#
 
-ALL_CASES = []
+ALL_CASES = {}
 """
-All test cases that have been created. Each is a `TestCase` object.
+All test cases that have been created, organized by test-suite names. By
+default all cases are added to the 'default' test suite, but this can be
+changed using `startTestSuite`. Each entry has a test suite name as the
+key and a list of `TestCase` objects as the value.
+"""
+
+_CURRENT_SUITE_NAME = "default"
+"""
+The name of the current test suite, which organizes newly-created test
+cases within the ALL_CASES variable. Use `startTestSuite` to begin/resume
+a new test suite, and `currentTestSuite` to retrieve the value.
 """
 
 COMPLETED_PER_LINE = {}
@@ -323,7 +333,7 @@ class TestCase:
         self.outcomes = []
 
         # Register as a test case
-        ALL_CASES.append(self)
+        ALL_CASES.setdefault(_CURRENT_SUITE_NAME, []).append(self)
 
     def provideInputs(self, *inputLines):
         """
@@ -1599,22 +1609,30 @@ def attendTrailingWhitespace(on=True):
     IGNORE_TRAILING_WHITESPACE = not on
 
 
-#---------------#
-# Summarization #
-#---------------#
+#---------------------------------#
+# Summarization and Case Tracking #
+#---------------------------------#
 
-def showSummary():
+def showSummary(suiteName=None):
     """
-    Shows a summary of the number of checks that have been met or not.
+    Shows a summary of the number of checks in the current test suite
+    (see `currentTestSuite`) that have been met or not. You can also
+    give an argument to specify the name of the test suite to summarize.
     Prints output to sys.stderr.
     """
+    if suiteName is None:
+        suiteName = currentTestSuite()
+
+    if suiteName not in ALL_CASES:
+        raise ValueError(f"Test suite '{suiteName}' does not exist.")
+
     # Flush stdout & stderr to improve ordering
     sys.stdout.flush()
     sys.stderr.flush()
 
     met = []
     unmet = []
-    for case in ALL_CASES:
+    for case in ALL_CASES[suiteName]:
         for passed, tag, msg in case.outcomes:
             if passed:
                 met.append(tag)
@@ -1658,6 +1676,76 @@ def showSummary():
     sys.stderr.flush()
 
 
+def currentTestSuite():
+    """
+    Returns the name of the current test suite (a string).
+    """
+    return _CURRENT_SUITE_NAME
+
+
+def startTestSuite(name):
+    """
+    Starts a new test suite with the given name, or resumes an old one.
+    Any cases created subsequently will be registered to that suite.
+    """
+    global _CURRENT_SUITE_NAME
+    if not isinstance(name, str):
+        raise TypeError(
+            f"The test suite name must be a string (got: '{repr(name)}'"
+            f" which is a {type(name)})."
+        )
+    _CURRENT_SUITE_NAME = name
+
+
+def resetTestSuite(suiteName=None):
+    """
+    Resets the cases recorded in the current test suite (or the named
+    test suite if an argument is provided).
+    """
+    if suiteName is None:
+        suiteName = currentTestSuite()
+
+    ALL_CASES[suiteName] = []
+
+
+def deleteAllTestSuites():
+    """
+    Deletes all test suites, removing all recorded test cases, and
+    setting the current test suite name back to "default".
+    """
+    global ALL_CASES, _CURRENT_SUITE_NAME
+    _CURRENT_SUITE_NAME = "default"
+    ALL_CASES = {}
+
+
+def listCasesInSuite(suiteName=None):
+    """
+    Returns a list of test cases (`TestCase` objects) in the current test
+    suite (or the named suite if an argument is provided).
+    """
+    if suiteName is None:
+        suiteName = currentTestSuite()
+
+    if suiteName not in ALL_CASES:
+        raise ValueError(f"Test suite '{suiteName}' does not exist.")
+
+    return ALL_CASES[suiteName][:]
+
+
+def listAllCases():
+    """
+    Returns a list of all registered test cases (`TestCase` objects) in
+    any known test suite. Note that if `deleteAllTestSuites` has been
+    called, this will not include any `TestCase` objects created before
+    that point.
+    """
+    result = []
+    for suiteName in ALL_CASES:
+        result.extend(ALL_CASES[suiteName])
+
+    return result
+
+
 #---------------#
 # Color control #
 #---------------#
